;;; All paths are ofcourse site dependant
;;; And some of the commands only works with specific packages installed (actually that goes for most of the settings)

; load local init - do NOT remove (Site specific please ignore)
(load "local")

;;;;; PACKAGES SECTION ;;;;;
;;; JDE - Java Development Environment.
(require 'jde)

;;;;; CUSTOMIZE SECTION ;;;;;
; Custom colours for emacs, and moves scrollbar to the right side of the screen,
; where scroolbars should be!
(custom-set-variables
 '(scroll-bar-mode (quote right))
 '(initial-frame-alist (quote ((foreground-color . "black") (background-color . "ivory"))))
 '(default-frame-alist (quote ((foreground-color . "black")
			       (background-color . "ivory")))))

; Set the colour and font face of the "modeline", the modeline indicates file
; opened and which modes are enable, line number etc.
(custom-set-faces
 '(modeline ((t (:foreground "gold" :background "navy")))))

;;; goto line C-cg line number
(global-set-key "\C-cg" 'goto-line)

;;; insert {} with C-{
(fset 'braces
   [?{ return return ?} tab ?\C-p tab])
(global-set-key [?\C-{] 'braces)

;;; BS - comfortable buffer selection
(require 'bs)
(global-set-key "\C-x\C-b" 'bs-show)
(global-set-key "\C-xB" 'buffer-menu)

;;; Remove top tool bar
;(tool-bar-mode 0)

;;; Auto syntax highlightning
(global-font-lock-mode t)

;;; Show matching paranteses
(show-paren-mode t)

;;; Visual feedback on selections
(setq-default transient-mark-mode t)

;;; Always end a file with a newline
;(setq require-final-newline t)

;;; Set up the keyboard so the delete key on both the regular keyboard
;;; and the keypad delete the character under the cursor and to the right
;;; under X, instead of the default, backspace behavior.
(global-set-key [delete] 'delete-char)
(global-set-key [kp-delete] 'delete-char)

;;; Break lines after 80 characters
(setq-default fill-column 80)
(auto-fill-mode 1)
(add-hook 'text-mode-hook 'turn-on-auto-fill)

;;; Silent bell, actually seems to work even under Solaris
;;; Makes emacs flash instead of the pc speaker yelling.
(setq visible-bell t)

;;; add TeX Support
(load "tex-site")

;;; User email adress (for use with emacs email clients etc)
(setq user-mail-address "esben@cs.aau.dk")
(custom-set-variables
 '(load-home-init-file t t))
(custom-set-faces)

;;; Changes ispell to britih dictionary
;(ispell-change-dictionary "british")

;;; Add the personal dictionary changes or additions alongside the already loaded dictionary
;(setq ispell-personal-dictionary "~/.ispell_personal")

;; RefTeX
(add-hook 'LaTeX-mode-hook 'turn-on-reftex) ; with AUCTeX LaTeX mode
(add-hook 'latex-mode-hook 'turn-on-reftex) ; with Emacs latex mode
(setq reftex-enable-partial-scans t)
(setq reftex-save-parse-info t)
(setq reftex-use-multiple-selection-buffers t)
(setq reftex-plug-into-AUCTeX t) ; integrate with AUCTeX

; Delete marked region
(global-set-key [(shift delete)] 'delete-region)

;;; Replace ispell with aspell (dictionary changes still works)
(setq-default ispell-program-name "aspell")

;;; Aspell-Flyspell setup
(dolist (hook '(latex-mode-hook))
   (add-hook hook (lambda () (flyspell-mode 1))))
(dolist (hook '(text-mode-hook))
   (add-hook hook (lambda () (flyspell-mode 1))))
(dolist (hook '(change-log-mode-hook log-edit-mode-hook))
   (add-hook hook (lambda () (flyspell-mode -1))))

;;; Bind key on mouse 4 and 5 for scroll (this is in most cases your actual
;;; scroll wheel)
      (defun up-slightly () (interactive) (scroll-up 5))
      (defun down-slightly () (interactive) (scroll-down 5))
      (global-set-key [mouse-4] 'down-slightly)
      (global-set-key [mouse-5] 'up-slightly)
      
      (defun up-one () (interactive) (scroll-up 1))
      (defun down-one () (interactive) (scroll-down 1))
      (global-set-key [S-mouse-4] 'down-one)
      (global-set-key [S-mouse-5] 'up-one)
      
      
      (defun up-a-lot () (interactive) (scroll-up))
      (defun down-a-lot () (interactive) (scroll-down))
      (global-set-key [C-mouse-4] 'down-a-lot)
      (global-set-key [C-mouse-5] 'up-a-lot)

;;; Personal keymap mode, which loads files (not open but LOAD, for instance if
;;; you want to reload the commands in your .emacs file you could use this)
(setq my-mode-map (make-keymap 'my-keymap))
(define-key my-mode-map "l" 'load-file)
(define-key global-map "\C-q" my-mode-map) ;; C-q was once used to quoted insert

;;; Laml support for emacs by Kurt Nrmark, Associate Professor of Computer
;;; Science on AAU.
(load "/pack/laml/emacs-support/dot-emacs-contribution.el")
